%Tracciamento dei dati relativi al transitorio di
%messa in tensione del trasformatore trifase
%
%
%Dati di Targa del Trasformatore:
%Sn=2.5     kVA
%V1n=380    V
%V2n=220    V   (YY)
%f=50       Hz
%Lo strumento digitale  sensibile a segnali di tensione
%quindi altri tipi di segnale (correnti, temperature, coppie ecc.)
%devono essere convertiti preventivamente in segnali del genere.
%Le portate dei canali CH6,CH7 e CH8 sono tutte pari a 400V,
%quindi i valori ad essi relativi sono gi espressi in valori veri.
%I canali CH1,CH2 e CH5 invece hanno una portata di 2000mV su 4 divisioni,
%ovvero 500mV/div. Avendo impostato la portata corrispondente di corrente
%pari a 5A/div, si ha la proporzione: 0.5V:5A=Vmis:i
%dove "Vmis" indica il valore misurato (in V) corrispondente al valore vero
%di corrente "i".
%Si ottiene: i=10*Vmis; ci spiega il perch le colonne
%1,2, e 3 della matrice "ABC" siano state moltiplicate per 10.



load ABC.mat;   %Caricamento dei dati registrati

fatt=10;        %Fattore di Decimazione del vettore ABC
ABC1=rid(ABC,fatt);


y1=10*ABC1(:,1);     %I1     (CH1)   [A]
y2=10*ABC1(:,2);     %I2     (CH2)   [A]
y3=10*ABC1(:,3);     %I3     (CH5)   [A]
y4=ABC1(:,4);        %V10    (CH6)   [V]
y5=ABC1(:,5);        %V20    (CH7)   [V]
y6=ABC1(:,6);        %V30    (CH8)   [V]

n=size(ABC1);    %Punti per canale prelevati (campionamento)
n=n(1);
ti=0;
tf=50;      %[ms]
dt=(tf-ti)/n;

t=ti:dt:tf-dt;


t0=17.85;          %Istante di chiusura [ms]
i=1;
while t(i)/t0<0.999 %Trova l'indice del valore
    i=i+1;          %corrispondente a t0
end
                  
                   
    
v100=y4(i);    %Valori iniziali di tensione
v200=y5(i);    %Valori iniziali di tensione
v300=y6(i);    %Valori iniziali di tensione

figure;
subplot(2,1,1),plot(t,y4,t,y5,t,y6);   %Plottaggio Tensioni
axis([0 50 -400 400]);
title('Andamento delle tensioni Concatenate',... 
   'FontWeight','bold');
xlabel('Tempo in [ms]');
ylabel('Tensione [V]');
line([t0 t0],[-400 400],'Color','m','LineStyle','--');
text(t0+0.5,-375,['t_0=',num2str(t0),' ms']);
text(18.8,308,'V_{10}');
text(24.7,356,'V_{20}');
text(31.9,332,'V_{30}');
line([0 t0],[v100 v100],'Color','m','LineStyle','--');
text(5,v100+25,'V_{10}(t_0)=307 V');
line([0 t0],[v200 v200],'Color','m','LineStyle','--');
text(5,v200-30,'V_{20}(t_0)=-181 V');
line([0 t0],[v300 v300],'Color','m','LineStyle','--');
text(5,v300+25,'V_{30}(t_0)=-126 V');





subplot(2,1,2),plot(t,y1,t,y2,t,y3);   %Plottaggio Correnti
axis([0 50 -10 15]);
title('Andamento delle Correnti',... 
   'FontWeight','bold');
xlabel('Tempo in [ms]');
ylabel('Corrente [A]');
line([t0 t0],[-10 15],'Color','m','LineStyle','--');
text(t0+0.5,-9,['t_0=',num2str(t0),' ms']);
text(27,12,'I_3');
text(28.5,-7.6,'I_2');
text(25.5,-4,'I_1');
line([0 25.8],[-4.8 -4.8],'Color','m','LineStyle','--');
text(5,-4.3,'I_1min=-4.8 A');
line([0 27.8],[-7 -7],'Color','m','LineStyle','--');
text(5,-8,'I_2min=-7.0 A');
line([0 26.6],[11.4 11.4],'Color','m','LineStyle','--');
text(5,12,'I_3max=11.4 A');

figure;
plot(t,y1+y2+y3);
title('Sommatoria delle Correnti',... 
   'FontWeight','bold');



